from .autoname import AutoNameByCount
from enum import auto

class Command(AutoNameByCount):
    aimode = auto()
    addtime = auto()
    addbot = auto()
    allvice = auto()
    ban = auto()
    cleartempbans = auto()
    cure = auto()
    changeteam = auto()
    changemap = auto()
    confetti = auto()
    clearchat = auto()
    clearrcon = auto()
    currentwave = auto()
    cmdlist = auto()
    comictext = auto()
    copylog = auto()
    drunk = auto()
    deletesave = auto()
    displayinfo = auto()
    decalclear = auto()
    detonatebomb = auto()
    endmatch = auto()
    eventtext = auto()
    echo = auto()
    explode = auto()
    explodebig = auto()
    forceweap = auto()
    flash = auto()
    freeze = auto()
    globalsound = auto()
    grappleplayers = auto()
    givevice = auto()
    kickbots = auto()
    kick = auto()
    kill = auto()
    killenemies = auto()
    killall = auto()
    killteam = auto()
    listdir = auto()
    localsound = auto()
    listsfx = auto()
    listmutators = auto()
    lobby = auto()
    listreckon = auto()
    move = auto()
    money = auto()
    matchtime = auto()
    memoryuse = auto()
    mutatorsetting = auto()
    moveteam = auto()
    moveenemies = auto()
    moveall = auto()
    networkinfo = auto()
    netcodetimerange = auto()
    netcodemargin = auto()
    netcodedamageallow = auto()
    netcodedistance = auto()
    netcodereset = auto()
    netcodedeathpredicttime = auto()
    netcodedeathpredictavg = auto()
    netcodedeathpredictping = auto()
    netcodereckon = auto()
    objreport = auto()
    pm = auto()
    powerup = auto()
    pause = auto()
    poison = auto()
    password = auto()
    playersound = auto()
    rawsay = auto()
    randbkgd = auto()
    resetvicesall = auto()
    resetvicesplayer = auto()
    restartmap = auto()
    restartround = auto()
    rcon = auto()
    rconget = auto()
    revive = auto()
    reviveall = auto()
    resetworld = auto()
    resetplayer = auto()
    resetallplayers = auto()
    resetmutatorsplayer = auto()
    reloadmutators = auto()
    say = auto()
    showcollision = auto()
    showtiles = auto()
    showpath = auto()
    setwave = auto()
    setvice = auto()
    spawnenemy = auto()
    setlife = auto()
    shock = auto()
    showlogic = auto()
    showplayerinfo = auto()
    skip = auto()
    showhitbox = auto()
    stopcmdlist = auto()
    spawnbody = auto()
    shootingrange = auto()
    showdps = auto()
    setrangetargets = auto()
    setmutatorplayer = auto()
    setbotaimode = auto()
    spawnvice = auto()
    showhud = auto()
    setbotaidivert = auto()
    test = auto()
    tempban = auto()
    thaw = auto()
    unbanlast = auto()
    unpause = auto()
    uptime = auto()
    zombending = auto()