from enum import Enum, auto

from .autoname import AutoName


class Hat(AutoName):
    no_hat = auto()
    ballin_cap = auto()
    military_cover = auto()
    constructing_helmet = auto()
    solid_bandana = auto()
    canadian_mask = auto()
    spas_hat = auto()
    the_tipper = auto()
    ten_gallon = auto()
    kings_adornment = auto()
    blue_soldier_aviator = auto()
    goldilocks = auto()
    raggy_rag = auto()
    protector = auto()
    suffocator = auto()
    the_entertainer = auto()
    mrowr_ears = auto()
    samurai_sunhat = auto()
    facial_cover = auto()
    bloody_mess = auto()
    twirly_bean = auto()
    bro_glasses = auto()
    chef_hat = auto()
    effed_up = auto()
    horny_helm = auto()
    cooking_pot = auto()
    party_hat = auto()
    fez = auto()
    night_vision = auto()
    riot_helmet = auto()
    wielders_delight = auto()
    sunny_hat = auto()
    funny_glasses = auto()
    the_brunette = auto()
    the_boss = auto()
    leather_hat = auto()
    sneaky_beaky = auto()
    roberts_hood = auto()
    oooshanka = auto()
    beer_hat = auto()
    duck_mask = auto()
    burger_boy = auto()
    sombreado = auto()
    the_sellout = auto()
    cool_backwards_hat = auto()
    ass_clown_wig = auto()
    paper_boat = auto()
    the_cosmonaut = auto()
    virtualized_goggles = auto()
    medical_mask = auto()
    tinfoil_hat = auto()
    dashing_topper = auto()
    conehead = auto()
    stupid_magic_hat = auto()
    bankroll_visor = auto()
    the_ol_arrow_gag = auto()
    santa_hat = auto()
    elf_ears = auto()
    frostman_mask = auto()
    stag_antlers = auto()
    hanukkah_headband = auto()
    kwanzaa_krown = auto()